@@ -1,13 +1,16 @@
 #
 # This file is part of Config-Model-Systemd
 #
-# This software is Copyright (c) 2015-2018 by Dominique Dumont.
+# This software is Copyright (c) 2008-2022 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-[
+use strict;
+use warnings;
+
+return [
   {
     'element' => [
       'service',
@@ -42,6 +45,7 @@
     'name' => 'Systemd',
     'rw_config' => {
       'auto_create' => '1',
+      'auto_delete' => '1',
       'backend' => 'Systemd'
     }
   }
